matchmaking

package module
v0.0.0-...-56ce8b6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 26, 2025 License: Apache-2.0 Imports: 19 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	ErrEmptyConfig = errors.New("service config is empty, please provide a valid config")
)

Functions

This section is empty.

Types

type InitOption

type InitOption func(*Service)

InitOption defines the signature for functional options.

func WithConfig

func WithConfig(config matchmakingconfig.Config) InitOption

WithConfig overrides the default configuration.

func WithLogger

func WithLogger(logger zerolog.Logger) InitOption

WithLogger overrides the default logger.

func WithVersion

func WithVersion(version string) InitOption

WithVersion overrides the default version.

type Service

type Service struct {
	// contains filtered or unexported fields
}

Service defines the dependencies that can be overridden when initializing a new matchmaking service.

func MustInitService

func MustInitService(ctx context.Context, opts ...InitOption) *Service

MustInitService initializes a new matchmaking service with the provided options. If an error occurs during initialization, the service will log the error and exit.

func NewService

func NewService(opts ...InitOption) (*Service, error)

NewService creates a new matchmaking service with the provided options.

func (*Service) Shutdown

func (s *Service) Shutdown()

shutdown closes all the resources used by the matchmaking service.

Directories

Path Synopsis
application
infrastructure
cli

Jump to